![OpenCore logo](https://github.com/acidanthera/OpenCorePkg/raw/master/Docs/Logos/OpenCore_with_text_Small.png)

# Vivobook-Pro 2-Opencore
macOS on the Ryzen 5800H Asus Vivobook Pro 2 thanks to [Acidanthera's OpenCore bootloader](https://github.com/acidanthera/OpenCorePkg).

## Disclaimer
This repository is neither a howto nor an installation manual. Using these files requires at least basic knowledge of [Acidanthera's OpenCore bootloader](https://github.com/acidanthera/OpenCorePkg), ACPI, UEFI and the art of hackintoshing in general. I recommend reading the excellent [Dortania's OpenCore Install Guide](https://dortania.github.io/OpenCore-Install-Guide), as well as all its linked resources.


## Recommendations
I recommend completely erasing the device's SSD by creating a new GPT partition table before attempting to install macOS, as it makes the installation process much easier. You may use any Linux live ISO with a partitioning tool such as `GParted` or `KPartition` to erase the SSD.

For macOS to be able to boot on this laptop, the `Secure Boot` option needs to be _**disabled**_ in the BIOS. If you still have the stock windows install you might need to punch in your bitlocker key. instructions will be available in the screen that shows up

Please be aware that all `PlatformInfo` and `SMBIOS` information was removed from the OpenCore `config.plist` files. Users will therefore need to generate their own `PlatformInfo` with [CorpNewt's GenSMBIOS tool](https://github.com/corpnewt/GenSMBIOS) before attempting to boot a Surface Go 2 with this repository's EFI folder.

` from the [OpenIntelWireless repo](https://github.com/OpenIntelWireless/itlwm) is required to enable the Wifi chip and was renamed to `AirportItlwm-Sonoma.kext` for the same reason.

The `kexts` required to enable the trackpad and the touchscreen are special versions of `VoodooI2C.kext` and `VoodooI2CHID.kext` [Modified with AMD support thanks to noot](https://chefkissinc.github.io/guide/gathering-files/kexts#input). Updating those `kexts` with the official ones from [the VoodooI2C repo](https://github.com/VoodooI2C) will most certainly break trackpad and touchscreen functionality! The `AirportItlwm.kext
## Software Specifications
| Software         | Version                            |
| ---------------- | ---------------------------------- |
| Target OS        | Apple macOS 13 Ventura (sonoma might also work) |
| OpenCore         | [OC v0.9.7](https://github.com/acidanthera/OpenCorePkg/releases/) |
| SMBIOS           | MacBookPro16,3 |
| SSD format       | APFS file system, GPT partition table |

## Computer Specifications
| Device           | Hardware                           |
| ---------------- | ---------------------------------- |
| CPU              | Ryzen 5800H |
| iGPU             | Nvidia RTX 3050 / Radeon Vega builtin |
| Audio            | Realtek ALC298 |
| RAM              | 2x8 GB LPDDR4 3200 MHz |
| Wifi + Bluetooth | Wifi6 AX200, Bluetooth 5.0 |
| Storage          | Kioxia/Toshiba 512 SSD |
| Front & Rear camera | Asus HD Camera |
| Keyboard / Trackpad | Microsoft Type Cover |
| Display | 15 inch 16:10 |
## What works
- [x] CPU power management (`SSDT-PLUG.aml, AMDRyzenCPUPowerManagement.kext`)
- [x] iGPU with full acceleration and temperature control (`NootedRed.kext, RadeonSensor`)
- [x] SSD drive (`NVMeFix.kext`)
- [x] WLAN (`AirportItlwm.kext`)
- [x] Bluetooth (`IntelBluetoothFirmware.kext`, `IntelBTPatcher.kext`, `BlueToolFixup.kext`)
- [x] Internal speakers, microphone (`AppleALC.kext`, `alcid=11`)
- [x] Power, volume up and volume down buttons (`VoodooPS2.kext`)
- [x] Touchpad ( `VoodooI2C.kext`, `VoodooI2CHID.kext`)
- [x] Battery percentage and cycle count
- [x] Light sensor for automatic brightness (`SMCLightSensor.kext`)

## Disabling sleep
As there is still no solution to the sleep issue on the laptop, it is recommended to disable Sleep altogether for now:
```
sudo pmset -a sleep 0
sudo pmset -a hibernatemode 0
sudo pmset -a disablesleep 1
```